# LoadDensity

---

### Locust Wrapper a framework for stress testing and load testing

#### Features
* HTTP HTTPS stress testing and load testing
* Action FIle
* response compare
* CLI with action file
---

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/JE-Chen/LoadDensity/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/JE-Chen/LoadDensity/tree/main)

[![LoadDensity GitHub Actions Dev](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_dev.yml)

[![LoadDensity GitHub Actions Stable](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/LoadDensity/actions/workflows/load-density-github-actions_stable.yml)

### Documentation
[![Documentation Status](https://readthedocs.org/projects/loaddensity/badge/?version=latest)](https://loaddensity.readthedocs.io/en/latest/?badge=latest)

https://loaddensity.readthedocs.io/en/latest/
---

## install 

```
pip install je_locust_wrapper
```

## require

```
python 3.7 or later  
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir